==> spirit_hub-0.0.1.11.tar.gz: spirit_hub-0.0.1.11/app/assets/javascripts/spirit_hub/controllers/searchable_select_controller.js <==
import { Controller } from '@hotwired/stimulus';
import { isEmailAddress } from 'helpers/emails';
import attachSlimSelectTo from 'helpers/attach_slimselect';

function debouncePromise(func, delay) {
  let timeout;
  let resolver;
  return (...args) => {
    return new Promise((resolve, reject) => {
      clearTimeout(timeout);
      timeout = setTimeout(() => {
        resolver = resolve;
        func(...args)
          .then(resolve)
          .catch(reject);
      }, delay);
    });
  };
}

export default class extends Controller {
  static targets = ['select'];

  connect() {
    this.searchRoute = this.element.dataset.searchRoute;
    this.contactAddable = this.element.dataset.contactAddable === 'true';

    const slimSelectConfig = {
      events: {
        search: debouncePromise(this.handleSearch.bind(this), 300),
      },
    };

    if (this.contactAddable) {
      slimSelectConfig.events.addable = value => {
        return isEmailAddress(value) && value;
      };
    }

    this.detachCallback = attachSlimSelectTo(this.element, slimSelectConfig);
  }

  disconnect() {
    this.detachCallback(this);
  }

  handleSearch(search) {
    return new Promise((resolve, reject) => {
      if (search.length < 3) {
        return reject('La recherche doit contenir au moins 3 caractères');
      }

      this.fetchSearchResults(search)
        .then(data => {
          if (!data.length) {
            return reject('Aucun résultat trouvé');
          }
          resolve(this.mapOptions(data));
        })
        .catch(() => {
          reject('Une erreur est survenue lors de la recherche.');
        });
    });
  }

  async fetchSearchResults(search) {
    const response = await fetch(`/spirit_hub/search/${this.searchRoute}?term=${search}`, {
      headers: { 'Content-Type': 'application/json' },
    });
    return response.json();
  }

  mapOptions(data) {
    return data.map(item => ({
      text: item.text,
      value: item.value,
    }));
  }
}

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/assets/javascripts/spirit_hub/controllers/searchable_select_controller.js <==
import { Controller } from '@hotwired/stimulus';
import { isEmailAddress } from 'helpers/emails';
import attachSlimSelectTo from 'helpers/attach_slimselect';

function debouncePromise(func, delay) {
  let timeout;
  let resolver;
  return (...args) => {
    return new Promise((resolve, reject) => {
      clearTimeout(timeout);
      timeout = setTimeout(() => {
        resolver = resolve;
        func(...args)
          .then(resolve)
          .catch(reject);
      }, delay);
    });
  };
}

export default class extends Controller {
  static targets = ['select'];

  connect() {
    this.searchRoute = this.element.dataset.searchRoute;
    this.contactAddable = this.element.dataset.contactAddable === 'true';

    const prefetchResults = this.element.dataset.prefetchResults === 'true';

    const slimSelectConfig = {
      events: {
        search: debouncePromise(this.handleSearch.bind(this), 300),
      },
      dataPromise: prefetchResults ? this.prefetchSearchResults() : null
    };

    if (this.contactAddable) {
      slimSelectConfig.events.addable = value => {
        return isEmailAddress(value) && value;
      };
    }

    this.detachCallback = attachSlimSelectTo(this.element, slimSelectConfig);
  }

  disconnect() {
    this.detachCallback(this);
  }

  handleSearch(search) {
    return new Promise((resolve, reject) => {
      if (search.length < 3) {
        return reject('La recherche doit contenir au moins 3 caractères');
      }

      this.fetchSearchResults(search)
        .then(data => {
          if (data.length) {
            resolve(data);
          } else {
            reject('Aucun résultat trouvé');
          }
        })
        .catch(() => {
          reject('Une erreur est survenue lors de la recherche.');
        });
    });
  }

  prefetchSearchResults() {
    return this.fetchSearchResults('');
  }

  async fetchSearchResults(search) {
    const response = await fetch(`/spirit_hub/search/${this.searchRoute}?term=${search}`, {
      headers: { 'Content-Type': 'application/json' },
    });

    const data = await response.json()

    if (!data?.length) return []

    return data.map(item => ({
      text: item.text,
      value: item.value,
      html: item.html
    }));
  }
}
